==> peaceful-progression-1.1.0-sources.jar: xen42/peacefulitems/entities/GhastlingFleeGoal.java <==
package xen42.peacefulitems.entities;

import java.util.EnumSet;
import net.minecraft.class_11;
import net.minecraft.class_1352;
import net.minecraft.class_1407;
import net.minecraft.class_1657;
import net.minecraft.class_243;
import net.minecraft.class_4051;
import net.minecraft.class_5530;
import net.minecraft.class_5533;
import xen42.peacefulitems.PeacefulModTags;

import org.jetbrains.annotations.Nullable;

public class GhastlingFleeGoal extends class_1352 {
   protected final GhastlingEntity mob;
   private final double fastSpeed;
   protected final float fleeDistance;
   @Nullable
   protected class_11 fleePath;
   protected final class_1407 fleeingEntityNavigation;
   private class_1657 target;

    protected double targetX;
    protected double targetY;
    protected double targetZ;

    protected boolean active;

   public GhastlingFleeGoal(GhastlingEntity mob, float distance, double fastSpeed) {
      this.mob = mob;
      this.fleeDistance = distance;
      this.fastSpeed = fastSpeed;
      this.fleeingEntityNavigation = (class_1407)mob.method_5942();
      this.method_6265(EnumSet.of(class_4134.field_18405));
   }

   public boolean method_6264() {
      if (!this.isInDanger()) {
         return false;
      } else {
         return this.findTarget();
      }
   }

   protected boolean isInDanger() {
    class_4051 predicate = class_4051.method_36626().method_18418(100f)
        .method_18420((entity) -> ((class_1657)entity).method_6047().method_31573(PeacefulModTags.ItemTags.WISP_DISLIKES));
      this.target = this.mob.method_37908().method_18462(predicate, this.mob);
      return this.target != null;
    }

   protected boolean findTarget() {
      class_243 vec3d = this.mob.method_5828(0.0F);
      class_243 vec3d2 = class_5533.method_31524(this.mob, 8, 7, vec3d.field_1352, vec3d.field_1350, 1.5707964F, 3, 1);
      vec3d = vec3d2 != null ? vec3d2 : class_5530.method_31504(this.mob, 8, 4, -2, vec3d.field_1352, vec3d.field_1350, 1.5707963705062866);

      if (vec3d == null) {
         return false;
      } else {
         this.targetX = vec3d.field_1352;
         this.targetY = vec3d.field_1351;
         this.targetZ = vec3d.field_1350;

         return true;
      }
   }

   public boolean isActive() {
      return this.active;
   }

   public void method_6269() {
      this.mob.method_5942().method_6337(this.targetX, this.targetY, this.targetZ, this.fastSpeed);
      this.active = true;
      this.mob.method_6013(null);
   }

   public void method_6270() {
      this.active = false;
   }

   public boolean method_6266() {
      return !this.mob.method_5942().method_6357();
   }
}

==> peaceful-progression-1.1.1-sources.jar: xen42/peacefulitems/entities/GhastlingFleeGoal.java <==
package xen42.peacefulitems.entities;

import java.util.EnumSet;
import net.minecraft.class_11;
import net.minecraft.class_1352;
import net.minecraft.class_1407;
import net.minecraft.class_1657;
import net.minecraft.class_243;
import net.minecraft.class_4051;
import net.minecraft.class_5530;
import net.minecraft.class_5533;
import xen42.peacefulitems.PeacefulModTags;

import org.jetbrains.annotations.Nullable;

public class GhastlingFleeGoal extends class_1352 {
   protected final GhastlingEntity mob;
   private final double fastSpeed;
   protected final float fleeDistance;
   @Nullable
   protected class_11 fleePath;
   protected final class_1407 fleeingEntityNavigation;
   private class_1657 target;

    protected double targetX;
    protected double targetY;
    protected double targetZ;

    protected boolean active;

   public GhastlingFleeGoal(GhastlingEntity mob, float distance, double fastSpeed) {
      this.mob = mob;
      this.fleeDistance = distance;
      this.fastSpeed = fastSpeed;
      this.fleeingEntityNavigation = (class_1407)mob.method_5942();
      this.method_6265(EnumSet.of(class_4134.field_18405));
   }

   public boolean method_6264() {
      if (!this.isInDanger()) {
         return false;
      } else {
         return this.findTarget();
      }
   }

   protected boolean isInDanger() {
    class_4051 predicate = class_4051.method_36626().method_18418(100f)
        .method_18420((entity, world) -> ((class_1657)entity).method_6047().method_31573(PeacefulModTags.ItemTags.WISP_DISLIKES));
      this.target = method_64451(this.mob).method_64388(predicate, this.mob);
      return this.target != null;
    }

   protected boolean findTarget() {
      class_243 vec3d = this.mob.method_5828(0.0F);
      class_243 vec3d2 = class_5533.method_31524(this.mob, 8, 7, vec3d.field_1352, vec3d.field_1350, 1.5707964F, 3, 1);
      vec3d = vec3d2 != null ? vec3d2 : class_5530.method_31504(this.mob, 8, 4, -2, vec3d.field_1352, vec3d.field_1350, 1.5707963705062866);

      if (vec3d == null) {
         return false;
      } else {
         this.targetX = vec3d.field_1352;
         this.targetY = vec3d.field_1351;
         this.targetZ = vec3d.field_1350;

         return true;
      }
   }

   public boolean isActive() {
      return this.active;
   }

   public void method_6269() {
      this.mob.method_5942().method_6337(this.targetX, this.targetY, this.targetZ, this.fastSpeed);
      this.active = true;
      this.mob.method_6013(null);
   }

   public void method_6270() {
      this.active = false;
   }

   public boolean method_6266() {
      return !this.mob.method_5942().method_6357();
   }
}
